==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/security/v1beta1/JWTHeaderFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JWTHeaderFluent<A extends JWTHeaderFluent<A>> extends BaseFluent<A>{
  public JWTHeaderFluent() {
  }
  public JWTHeaderFluent(JWTHeader instance) {
    instance = (instance != null ? instance : new JWTHeader());

    if (instance != null) {
      this.withName(instance.getName());
      this.withPrefix(instance.getPrefix());
      this.withName(instance.getName());
      this.withPrefix(instance.getPrefix());
    }
  }
  private String name;
  private String prefix;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getPrefix() {
    return this.prefix;
  }
  public A withPrefix(String prefix) {
    this.prefix=prefix; return (A) this;
  }
  public boolean hasPrefix() {
    return this.prefix != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JWTHeaderFluent that = (JWTHeaderFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(prefix, that.prefix)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  prefix,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (prefix != null) { sb.append("prefix:"); sb.append(prefix); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/security/v1beta1/JWTHeaderFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class JWTHeaderFluent<A extends JWTHeaderFluent<A>> extends BaseFluent<A>{
  public JWTHeaderFluent() {
  }
  
  public JWTHeaderFluent(JWTHeader instance) {
    this.copyInstance(instance);
  }
  private String name;
  private String prefix;
  
  protected void copyInstance(JWTHeader instance) {
    instance = (instance != null ? instance : new JWTHeader());
  
    if (instance != null) {
        this.withName(instance.getName());
        this.withPrefix(instance.getPrefix());
        this.withName(instance.getName());
        this.withPrefix(instance.getPrefix());
      }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getPrefix() {
    return this.prefix;
  }
  
  public A withPrefix(String prefix) {
    this.prefix=prefix; return (A) this;
  }
  
  public boolean hasPrefix() {
    return this.prefix != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JWTHeaderFluent that = (JWTHeaderFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(prefix, that.prefix)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  prefix,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (prefix != null) { sb.append("prefix:"); sb.append(prefix); }
    sb.append("}");
    return sb.toString();
  }
  

}
